#
# spec file for package python-duckduckgo-search
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-duckduckgo-search
Version:        7.1.1
Release:        1.1
Summary:        Search using the DuckDuckGo.com search engine
License:        MIT
URL:            https://github.com/deedy5/duckduckgo_search
Source:         https://files.pythonhosted.org/packages/source/d/duckduckgo-search/duckduckgo_search-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module click >= 8.1.7}
BuildRequires:  %{python_module primp >= 0.6.3}
# /SECTION
BuildRequires:  fdupes
Requires:       python-click >= 8.1.7
Requires:       python-primp >= 0.6.3
Suggests:       python-lxml >= 5.2.2
Suggests:       python-mypy >= 1.11.1
Suggests:       python-pytest >= 8.3.1
Suggests:       python-pytest-asyncio >= 0.23.8
Suggests:       python-ruff >= 0.6.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Search for words, documents, images, news, maps and text translation using the DuckDuckGo.com search engine. Downloading files and images to a local hard drive.

%prep
%autosetup -p1 -n duckduckgo_search-%{version}
chmod 0644 README.md
chmod 0644 LICENSE.md

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ddgs
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# NOTE: disable running tests as they require internet access by making calls to
# https://duckduckgo.com

%post
%python_install_alternative ddgs

%postun
%python_uninstall_alternative ddgs

%files %{python_files}
%doc README.md
%license LICENSE.md
%python_alternative %{_bindir}/ddgs
%{python_sitelib}/duckduckgo_search
%{python_sitelib}/duckduckgo_search-%{version}.dist-info

%changelog
* Thu Jan  2 2025 Dirk Müller <dmueller@suse.com>
- update to 7.1.1:
  * DDGS.text: deprecate backend='api'
- update to 7.1.0:
  * add backend="ecosia"
  * DDGS._impersonates: delete okhttp*
  * DDGS.text: reduce pagination
- update to 7.0.2:
  * Bump primp to v0.9.2
- update to 7.0.1:
  * [simplify]: remove AsyncDDGS, remove `answers`, `maps`,
    `suggestions`, `translate`; [text]: remove multithreading
  * [DDGS.text]: add backend="auto", [DDGS.images|news|videos]:
    remove multithreading
- update to 6.4.2:
  * use env var DDGS_PROXY
  * utils: _text_extract_json() bugfix
- update to 6.3.7:
  * added armv7 compatibility: Bump primp to v0.8.1
- update to 6.3.6:
  * Bump primp version to v0.8.0
  * DDGS._impersonates: add "chrome_131"
  * CLI: _download_file: impersonate="chrome_131"
  * CLI: --max_results=None by default; remove default=None
- update to 6.3.5:
  * CLI: 1)`-dd` to specify custom download directory, 2) `-o`
    can now set full filename
  * CLI: text() max_results=10 default
  * text(): update pagination logic (0, 10, 25, 40, ...)
  * text(): max(max_results)=190
  * videos(): max(max_results)=200
  * tests: text() max_results=20
  * README: update examples, remove httpx version info
- update to 6.3.4:
  * CLI: images license parameter - add ShareCommercially
  * CLI: _download_file: impersonate="chrome_130"
- update to 6.3.3:
  * Bump primp version to >=0.6.5
  * DDGS._impersonates: add "chrome_130"
- update to 6.3.2:
  * Add `verify` parameter to skip SSL verification when making
    the requests
- update to 6.3.1:
  * DDGS._impersonates: updated
  * primp.Client: verify=True
  * primp: bump version to v0.6.4
- update to 6.3.0:
  * DDGS._get_vqd(): use "GET" request
  * update tests
  * cli._download_file(): use impersonate="chrome_129"
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 6.2.13:
  * Bump primp to v0.6.3
  * DDGS._impersonates: add chrome_129, safari_18, safari_ipad_18
  * README: proxy section - change socks5:// to socks5h://
- update to 6.2.12:
  * fix _normalize_url() - replace space after unquote
  * Update requrements: bump primp to v0.6.2
  * DDGS._impersonates: add chrome_128
  * CLI: _download_file - set impersonate=chrome_128
* Wed Sep 11 2024 Guang Yee <gyee@suse.com>
- Release v6.2.11
